GetSMD: Compute Standardized Mean Differences (SMD)

View source: R/utility_functions.R

GetSMDR Documentation

Compute Standardized Mean Differences (SMD)

Description

Computes the standardized mean differences for covariates before and after adjustment.

Usage

GetSMD(data, treat, weights = NULL, std = TRUE)

Arguments

data

A data frame containing covariates.

treat

A binary variable indicating treatment assignment.

weights

Optional weight vector.

std

Logical; whether to standardize.

Value

A data frame with covariate names and their standardized mean differences.


debiasedTrialEmulation documentation built on March 20, 2026, 1:07 a.m.